/***************************************************************************

  joydev.h

  Joystick devices component

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __JOYDEV_H
#define __JOYDEV_H

#include <stdint.h>
#include <sys/types.h>

#define MAX_NAME_LENGTH 128

#define ERROR		-1
#define NO_EVENT	0
#define JOY_BUTTON	1
#define JOY_AXIS	2

#define BTN_PRESSED	1
#define BTN_RELEASED	0

typedef struct {
	char name[MAX_NAME_LENGTH];
	uint8_t axises;
	uint8_t buttons;

	int fd;
	char path[MAX_NAME_LENGTH];
} joyinfo;

typedef struct {
	int type;	/* JOY_BUTTON / JOY_AXIS / NO_EVENT / ERROR */
	uint8_t number;	/* axis/button number // error code number*/
	int16_t value; 	/* button status/ axis value */
} joyevent;

char errormsg[MAX_NAME_LENGTH];

/* Initialize joystick devices
   Return true on success */
int joydev_init(void );

/* Get infos about a joystick device */
int joydev_opendevice(char *device, joyinfo *joystick);

/* Close an opened joystick device */
void joydev_closedevice(joyinfo *joystick);

/* Get events from joystick */
void joydev_getevents(joyinfo *joystick, joyevent *event);

#endif /* __JOYDEV_H */
